# 👀 What's New

## 🏷️ 2.7.3

- 🌃 Background package added
- 🎨 Colorful log added
- ✨ Logging improved

## 🏷️ 2.7.2

- 👨‍🔧 Package names fixed
- 📦 `cli` packages created
- 📝 Documentation renewed
- ✨ `regex` module improved

## 🏷️ 2.7.0

- ➕ `ythemecreator` added
- 📜 Logging system built
- 📝 Documentations renewed
- 👨‍🔧 Links fixed
